pg.ddx.io  pgsql-committers@postgresql.org mailing list archive  
help / color / mirror / Atom feed
From: Peter Eisentraut <peter@eisentraut.org>
To: Alexander Korotkov <akorotkov@postgresql.org>
To: pgsql-committers@lists.postgresql.org
Subject: Re: pgsql: Use WAIT FOR LSN in PostgreSQL::Test::Cluster::wait_for_catchup(
Date: Tue, 7 Apr 2026 13:50:03 +0200
Message-ID: <d77e8d61-21ab-4728-ae3b-5303c36904d3@eisentraut.org> (raw)
In-Reply-To: <E1w9pvB-003HW2-1E@gemulon.postgresql.org>
References: <E1w9pvB-003HW2-1E@gemulon.postgresql.org>

On 06.04.26 21:47, Alexander Korotkov wrote:
> Use WAIT FOR LSN in PostgreSQL::Test::Cluster::wait_for_catchup()

This change appears to have made the "make check-world" run 
significantly slower.  In some of my testing, this changed the total run 
time from about 3min 30s to 4min 30s.  (Obviously, the absolute numbers 
will vary, but it's about a 25% increase.)






view thread (4+ messages)  latest in thread

Message-ID: <d77e8d61-21ab-4728-ae3b-5303c36904d3@eisentraut.org>
Permalink:  ../d77e8d61-21ab-4728-ae3b-5303c36904d3@eisentraut.org/
Also on:    postgresql.org/message-id/d77e8d61-21ab-4728-ae3b-5303c36904d3@eisentraut.org

 · 

reply

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Reply to all the recipients using the --to and --cc options:
  reply via email

  To: pgsql-committers@postgresql.org
  Cc: peter@eisentraut.org, akorotkov@postgresql.org, pgsql-committers@lists.postgresql.org
  Subject: Re: pgsql: Use WAIT FOR LSN in PostgreSQL::Test::Cluster::wait_for_catchup(
  In-Reply-To: <d77e8d61-21ab-4728-ae3b-5303c36904d3@eisentraut.org>

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

This inbox is served by DDX for PostgreSQL; see mirroring instructions
for how to clone and mirror all data and code used for this inbox